@@ -40,7 +40,7 @@ import pyflakes.messages
 import pyflakes.reporter
 
 
-__version__ = "1.7.0"
+__version__ = "1.7.1"
 
 
 _LOGGER = logging.getLogger("autoflake")
@@ -1245,8 +1245,9 @@ def merge_configuration_file(args):
                         name,
                     )
                     return False
-                if value:
-                    setattr(args, name.replace("-", "_"), value)
+                arg = name.replace("-", "_")
+                if value and not hasattr(args, arg):
+                    setattr(args, arg, value)
             else:
                 _LOGGER.error("'%s' is not a valid configuration option", name)
                 return False
